==> aws-java-sdk-cloudformation-1.9.34-sources.jar: com/amazonaws/services/cloudformation/model/transform/DescribeStackEventsResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudformation.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudformation.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Describe Stack Events Result StAX Unmarshaller
 */
public class DescribeStackEventsResultStaxUnmarshaller implements Unmarshaller<DescribeStackEventsResult, StaxUnmarshallerContext> {

    public DescribeStackEventsResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DescribeStackEventsResult describeStackEventsResult = new DescribeStackEventsResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return describeStackEventsResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("StackEvents/member", targetDepth)) {
                    describeStackEventsResult.getStackEvents().add(StackEventStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("NextToken", targetDepth)) {
                    describeStackEventsResult.setNextToken(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeStackEventsResult;
                }
            }
        }
    }

    private static DescribeStackEventsResultStaxUnmarshaller instance;
    public static DescribeStackEventsResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new DescribeStackEventsResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-cloudformation-1.10.43-sources.jar: com/amazonaws/services/cloudformation/model/transform/DescribeStackEventsResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudformation.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudformation.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DescribeStackEventsResult StAX Unmarshaller
 */
public class DescribeStackEventsResultStaxUnmarshaller implements
        Unmarshaller<DescribeStackEventsResult, StaxUnmarshallerContext> {

    public DescribeStackEventsResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        DescribeStackEventsResult describeStackEventsResult = new DescribeStackEventsResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return describeStackEventsResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("StackEvents/member", targetDepth)) {
                    describeStackEventsResult.getStackEvents().add(
                            StackEventStaxUnmarshaller.getInstance()
                                    .unmarshall(context));
                    continue;
                }

                if (context.testExpression("NextToken", targetDepth)) {
                    describeStackEventsResult
                            .setNextToken(StringStaxUnmarshaller.getInstance()
                                    .unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeStackEventsResult;
                }
            }
        }
    }

    private static DescribeStackEventsResultStaxUnmarshaller instance;

    public static DescribeStackEventsResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeStackEventsResultStaxUnmarshaller();
        return instance;
    }
}
